# FindLibJsonSpirit - Find libjson_spirit headers and libraries.
#
# Sample:
#
#   SET( LibJsonSpirit_USE_STATIC_LIBS OFF )
#   FIND_PACKAGE( LibJsonSpirit REQUIRED )
#   IF( LibJsonSpirit_FOUND )
#      INCLUDE_DIRECTORIES( ${LibJsonSpirit_INCLUDE_DIRS} )
#      TARGET_LINK_LIBRARIES( ... ${LibJsonSpirit_LIBRARIES} )
#   ENDIF()
#
# Variables used by this module need to be set before calling find_package
#
#   LibJsonSpirit_USE_STATIC_LIBS	Can be set to ON to force the use of the static
#					libjson_spirit libraries. Defaults to OFF.
#
# Variables provided by this module:
#
#   LibJsonSpirit_FOUND		Include dir, libjson_spirit libraries.
#
#   LibJsonSpirit_LIBRARIES	Link to these to use all the libraries you specified.
#
#   LibJsonSpirit_INCLUDE_DIRS	Include directories.
#
# For each component you specify in find_package(), the following (UPPER-CASE)
# variables are set to pick and choose components instead of just using
# LibJsonSpirit_LIBRARIES:
#
#   LIBJSONSPIRIT_FOUND			TRUE if libjson_spirit was found
#   LIBJSONSPIRIT_LIBRARY		libjson_spirit library
#

# Support preference of static libs by adjusting CMAKE_FIND_LIBRARY_SUFFIXES
IF(LibJsonSpirit_USE_STATIC_LIBS)
    SET( _ORIG_CMAKE_FIND_LIBRARY_SUFFIXES ${CMAKE_FIND_LIBRARY_SUFFIXES})
    SET(CMAKE_FIND_LIBRARY_SUFFIXES .a )
ENDIF()

# Look for the header files
UNSET(LibJsonSpirit_INCLUDE_DIRS CACHE)
FIND_PATH(LibJsonSpirit_INCLUDE_DIRS NAMES json_spirit.h)

# Look for the core library
UNSET(LIBJSONSPIRIT_LIBRARY CACHE)
FIND_LIBRARY(LIBJSONSPIRIT_LIBRARY NAMES json_spirit)
FIND_PACKAGE_HANDLE_STANDARD_ARGS(LibJsonSpirit DEFAULT_MSG LIBJSONSPIRIT_LIBRARY LibJsonSpirit_INCLUDE_DIRS)
MARK_AS_ADVANCED(
    LIBJSONSPIRIT_FOUND
    LIBJSONSPIRIT_LIBRARY
)

# Prepare return values and collectiong more components
SET(LibJsonSpirit_FOUND ${LIBJSONSPIRIT_FOUND})
SET(LibJsonSpirit_LIBRARIES ${LIBJSONSPIRIT_LIBRARY})
MARK_AS_ADVANCED(
    LibJsonSpirit_FOUND
    LibJsonSpirit_LIBRARIES
    LibJsonSpirit_INCLUDE_DIRS
)

# Restore CMAKE_FIND_LIBRARY_SUFFIXES
IF(LibJsonSpirit_USE_STATIC_LIBS)
    SET(CMAKE_FIND_LIBRARY_SUFFIXES ${_ORIG_CMAKE_FIND_LIBRARY_SUFFIXES} )
ENDIF()
